==> owncloud-9.0.3.tgz: owncloud/apps/files_external/l10n/de.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Please provide a valid app key and secret." : "Bitte trage einen gültigen App-Key mit Secret ein.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "External storage" : "Externer Speicher",
    "Storage with id \"%i\" not found" : "Der Speicher mit der ID „%i“ wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültiger Backend- oder Authentifizierungsmechanismus",
    "Invalid mount point" : "Ungültiger mount point",
    "Objectstore forbidden" : "Objekt nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicher-Backend „%s“",
    "Not permitted to use backend \"%s\"" : "Nicht zulässig Backend \"%s\" zu verwenden",
    "Not permitted to use authentication mechanism \"%s\"" : "verwende zulässigen Authentifizierungsmechanismus \"%s\" ",
    "Unsatisfied backend parameters" : "Unbefriedigende Backend- Parameter",
    "Unsatisfied authentication mechanism parameters" : "Unbefriedigende Authentifizierungsmechanismus Parameter",
    "Insufficient data: %s" : "Unzureichende Daten: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Speicher mit der ID \"%i\" kann nicht vom Benutzer bearbeitet werden",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Zugriff gestatten",
    "Access granted" : "Zugriff gestattet",
    "Error configuring OAuth1" : "Fehler beim konfigurieren von OAuth1",
    "Error configuring OAuth2" : "Fehler beim Einrichten von OAuth2",
    "Generate keys" : "Schlüssel erzeugen",
    "Error generating key pair" : "Fehler beim Erzeugen des Schlüsselpaares",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Enable sharing" : "Freigaben einschalten",
    "Check for changes" : "Auf Änderungen überprüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem Direktzugriff",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Admin defined" : "Administrator festlegen",
    "Saved" : "Gespeichert",
    "Empty response from the server" : "leere Antowrt vom Server",
    "Couldn't access. Please logout and login to activate this mount point" : "Anmeldung nicht möglich. Bitte melde dich ab und wieder an, damit du von diesem Endpunkt zugreifen kannst.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Es konnten keine Informationen aus dem ownCloud -Server gelesen werden: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Die Liste der externen Endpunkte konnte nicht empfangen werden: {type}",
    "There was an error with message: " : "Es ist ein Fehler mit folgender Meldung aufgetreten:",
    "External mount error" : "Fehler beim einbinden des externen Speichers",
    "external-storage" : "Externer Speicher",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Es konnte keine Liste der Windows Netzlaufwerk erstellt werden: leer Antwort vom Server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Einige der konfigurierten externen Bereitstellungspunkte  sind nicht angeschlossen. Bitte klicke auf die roten Zeile(n) für weitere Informationen",
    "Please enter the credentials for the {mount} mount" : "Bitte gib die Anmeldeinformationen für den {mount} externen Bereitstellungspunkt ein",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Credentials saved" : "Anmeldeinformationen gespeichert",
    "Credentials saving failed" : "speichern der Anmeldeinformationen fehlgeschlagen",
    "Credentials required" : "Anmeldeinformationen benötigt",
    "Save" : "Speichern",
    "Access key" : "Zugangsschlüssel",
    "Secret key" : "Geheimer Schlüssel",
    "Builtin" : "eingebaut",
    "None" : "Keine",
    "OAuth1" : "OAuth1",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "OAuth2" : "OAutch2",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Name des Mieters",
    "Identity endpoint URL" : "Identität Endpunkt-URL",
    "Rackspace" : "Rackspace",
    "API key" : "API-Schlüssel",
    "Username and password" : "Benutzername und Passwort",
    "Log-in credentials, save in session" : "Anmeldedaten in Sitzung speichern",
    "RSA public key" : "RSA öffentlicher Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfad-Stil aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicherer HTTPS://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicherer ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Ort",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit dem Login über einen geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Login",
    "Username as share" : "Benutzername als Freigabe",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Service name" : "Service Name",
    "Request timeout (seconds)" : "Anfrage -Timeout ( Sekunden)",
    "<b>Note:</b> " : "<b>Hinweis:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die cURL-Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich zur Installation an Deinen Systemadministrator.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die FTP Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich sich zur Installation an Deinen Systemadministrator.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> \"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich sich zur Installation an Deinen Systemadministrator.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Du kannst externe Speicher in den persönlichen Einstellungen hinzufügen",
    "Name" : "Name",
    "Storage type" : "Du hast noch keinen externen Speicher",
    "Scope" : "Anwendungsbereich",
    "External Storage" : "Externer Speicher",
    "Folder name" : "Ordnername",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Allow users to mount external storage" : "Benutzern erlauben, externen Speicher einzubinden",
    "Allow users to mount the following external storage" : "Benutzern erlauben, den oder die folgenden externen Speicher einzubinden:",
    "SMB / CIFS" : "SMB / CIFS",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Einige der konfigurierten externen Bereitstellungspunkte  sind nicht angeschlossen. Bitte klicke auf die roten Zeile(n) für weitere Informationen"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.3.tgz: owncloud/apps/files_external/l10n/de.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Please provide a valid app key and secret." : "Bitte trage einen gültigen App-Key mit Secret ein.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "External storage" : "Externer Speicher",
    "Dropbox App Configuration" : "Dropbox-App Konfiguration",
    "Google Drive App Configuration" : "Google Drive - App Konfiguration",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Zugriff gestatten",
    "Error configuring OAuth1" : "Fehler beim konfigurieren von OAuth1",
    "Error configuring OAuth2" : "Fehler beim Einrichten von OAuth2",
    "Generate keys" : "Schlüssel erzeugen",
    "Error generating key pair" : "Fehler beim Erzeugen des Schlüsselpaares",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilität mit MAC NFD-Kodierung (langsam)",
    "Admin defined" : "Administrator festlegen",
    "Saved" : "Gespeichert",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Das Deaktivieren des externen Speichers entfernt bei allen Nutzern alle Speicher. Bist du dir sicher?",
    "Disable external storage" : "Externen Speicher deaktivieren",
    "Empty response from the server" : "leere Antowrt vom Server",
    "Couldn't access. Please logout and login to activate this mount point" : "Anmeldung nicht möglich. Bitte melde dich ab und wieder an, damit du von diesem Endpunkt zugreifen kannst.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Es konnten keine Informationen aus dem ownCloud -Server gelesen werden: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Die Liste der externen Endpunkte konnte nicht empfangen werden: {type}",
    "There was an error with message: " : "Es ist ein Fehler mit folgender Meldung aufgetreten:",
    "External mount error" : "Fehler beim einbinden des externen Speichers",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Es konnte keine Liste der Windows-Netzlaufwerke erstellt werden: leer Antwort vom Server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Einige der konfigurierten externen Bereitstellungspunkte  sind nicht angeschlossen. Bitte klicke auf die roten Zeile(n) für weitere Informationen",
    "Please enter the credentials for the {mount} mount" : "Bitte gib die Anmeldeinformationen für den {mount} externen Bereitstellungspunkt ein",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Credentials saved" : "Anmeldeinformationen gespeichert",
    "Credentials saving failed" : "speichern der Anmeldeinformationen fehlgeschlagen",
    "Credentials required" : "Anmeldeinformationen benötigt",
    "Save" : "Speichern",
    "Storage with id \"%i\" not found" : "Der Speicher mit der ID „%i“ wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültiger Backend- oder Authentifizierungsmechanismus",
    "Invalid mount point" : "Ungültiger mount point",
    "Objectstore forbidden" : "Objekt nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicher-Backend „%s“",
    "Not permitted to use backend \"%s\"" : "Nicht zulässig Backend \"%s\" zu verwenden",
    "Not permitted to use authentication mechanism \"%s\"" : "verwende zulässigen Authentifizierungsmechanismus \"%s\" ",
    "Unsatisfied backend parameters" : "Unbefriedigende Backend- Parameter",
    "Unsatisfied authentication mechanism parameters" : "Unbefriedigende Authentifizierungsmechanismus Parameter",
    "Insufficient data: %s" : "Unzureichende Daten: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Speicher mit der ID \"%i\" kann nicht vom Benutzer bearbeitet werden",
    "Access key" : "Zugangsschlüssel",
    "Secret key" : "Geheimer Schlüssel",
    "OAuth1" : "OAuth1",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Name des Mieters",
    "Identity endpoint URL" : "Identität Endpunkt-URL",
    "Rackspace" : "Rackspace",
    "API key" : "API-Schlüssel",
    "RSA public key" : "RSA öffentlicher Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfad-Stil aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicherer HTTPS://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Ort",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Host",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit dem Login über einen geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Login",
    "Username as share" : "Benutzername als Freigabe",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Service name" : "Service Name",
    "Request timeout (seconds)" : "Anfrage -Timeout ( Sekunden)",
    "<b>Note:</b> " : "<b>Hinweis:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die cURL-Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich zur Installation an Deinen Systemadministrator.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> \"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich sich zur Installation an Deinen Systemadministrator.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the storage settings" : "Du kannst externe Speicher in den Speicher-Einstellungen hinzufügen",
    "Name" : "Name",
    "Storage type" : "Du hast noch keinen externen Speicher",
    "Scope" : "Anwendungsbereich",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Enable sharing" : "Freigaben einschalten",
    "Check for changes" : "Auf Änderungen überprüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem Direktzugriff",
    "External Storage" : "Externer Speicher",
    "Enable external storage" : "Externen Speicher aktivieren",
    "External storage has been disabled by the administrator" : "Der externe Speicher wurde durch den Administrator deaktiviert",
    "Folder name" : "Ordnername",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Allow users to mount external storage" : "Benutzern erlauben, externen Speicher einzubinden",
    "Allow users to mount the following external storage" : "Benutzern erlauben, den oder die folgenden externen Speicher einzubinden:"
},
"nplurals=2; plural=(n != 1);");
